/* 
 * delfin.c
 *
 * Copyright (C) 1997,1998 Hermann Samso <ukra@rz.uni-karlsruhe.de>
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.               
 *
 */

#include <stdio.h>
#include <stdlib.h>
#include <unistd.h>
#include <stdarg.h>
#include <time.h>
#include <signal.h>
#include <string.h>
#include <getopt.h>
#include <ncurses.h>
#include "delfin.h"
#include "wave.h"
#include "audiodrv.h"
#include "module.h"
#include "display.h"

BOOL trace_on = FALSE;				// function trace_on flag, for debugging 
 
int main(int argc, char **argv) {
	INT i = 0;
	CHAR* save_actual_module = NULL;
	INT optch;
	static CHAR cmdopts[] = {
		't', 'h', 0 };
	INT input = 0;
	BOOL quit = FALSE;
			
	while ((optch = getopt(argc, argv, cmdopts)) != -1)
		switch (optch) {
			case 't' :
				trace_on = TRUE;
				break;
			case 'h' :
				usage();
				exit(0);
			default:
				usage();
				exit(1);
		}

	AudioInit(SOUNDDEV, 44100, 16, 1, 128);
	DisplayInit();
	DisplayDelfin();

	ModuleRegisterAll();
	ModuleDisplay();
	WaveDisplay();
			

	while (quit == FALSE) {

		// Execute all modules
		save_actual_module = ModuleGetName();	// 1st save actual module
		ModuleFirst();
		for (i = 0; i < ModuleHowMany(); i++) {
			ModuleExec();
			ModuleNext();
		}
		ModuleSelectByName(save_actual_module);	// restore module
		
		input = getch();
		if (input != ERR) {
			switch (input) {
				case 27:
					quit = TRUE;
					if (AudioOpened())
						AudioClose();
					break;
				case KEY_F(12):
					ModuleSelectByName("wave");
					break;
				case KEY_RIGHT:
					WaveNext();
					ModuleDisplay();
					break;
				case KEY_LEFT:
					WavePrevious();
					ModuleDisplay();
					break;
				case KEY_UP:
					ModulePrevious();
					ModuleDisplay();
					break;
				case KEY_DOWN:
					ModuleNext();
					ModuleDisplay();
					break;
				default:
					ModuleCtrl(input);
					break;
			}
		}
	}

	DisplayExit();
	return(0);	
}


void usage(void) {
	printf("Usage:\tdelfin [options]\n\n");
	printf("Options:\n");
	printf("\t-t\tTrace mode for debugging\n");
	printf("\t-h\tThis text\n");
}
